#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-info
version:              0.2.0.10
visibility:           public
id:                   network-info-0.2.0.10-9tBDnpf4RI1CDFbuwuYidN
key:                  network-info-0.2.0.10-9tBDnpf4RI1CDFbuwuYidN
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             http://github.com/jystic/network-info
synopsis:             Access the local computer'\''s basic network configuration
description:
    This library provides simple read-only access to the
    local computer'\''s networking configuration. It is
    currently capable of getting a list of all the network
    interfaces and their respective IPv4, IPv6 and MAC
    addresses.

    network-info has been tested and is known to work on
    Ubuntu 10.10, FreeBSD 9.0, Mac OS X 10.6.4 and Windows
    XP/7. It probably works on other flavours of Linux,
    OS X, FreeBSD and Windows as well.

category:             Network
abi:                  57d0db4651aa172cdadba3b1b15e2ac5
exposed:              True
exposed-modules:      Network.Info
import-dirs:          /usr/lib/ghc-8.10.5/site-local/network-info-0.2.0.10
library-dirs:         /usr/lib/ghc-8.10.5/site-local/network-info-0.2.0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/network-info-0.2.0.10
hs-libraries:         HSnetwork-info-0.2.0.10-9tBDnpf4RI1CDFbuwuYidN
depends:              base-4.14.2.0
haddock-interfaces:
    /usr/share/doc/haskell-network-info/html/network-info.haddock

haddock-html:         /usr/share/doc/haskell-network-info/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

